@@ -65,6 +65,7 @@ static bool rewrite_timestamp_insert(InsertStmt *i_stmt, TSRewriteContext *ctx);
 static bool rewrite_timestamp_update(UpdateStmt *u_stmt, TSRewriteContext *ctx);
 static char *get_current_timestamp(POOL_CONNECTION_POOL *backend);
 static Node *makeTsExpr(TSRewriteContext *ctx);
+static TypeCast *makeTypeCastFromSvfOp(SQLValueFunctionOp op);
 static A_Const *makeStringConstFromQuery(POOL_CONNECTION_POOL *backend, char *expression);
 bool raw_expression_tree_walker(Node *node, bool (*walker) (), void *context);
 
@@ -129,10 +130,7 @@ ts_unregister_func(void *data)
 static TSRel*
 relcache_lookup(TSRewriteContext *ctx)
 {
-#define ATTRDEFQUERY (Pgversion(ctx->backend)->major >= 73 ? \
-	"SELECT attname, pg_get_expr(d.adbin, d.adrelid), coalesce((pg_get_expr(d.adbin, d.adrelid) LIKE '%%now()%%' OR pg_get_expr(d.adbin, d.adrelid) LIKE '%%''now''::text%%' OR" \
-	" pg_get_expr(d.adbin, d.adrelid) LIKE '%%CURRENT_TIMESTAMP%%' OR pg_get_expr(d.adbin, d.adrelid) LIKE '%%CURRENT_TIME%%' OR pg_get_expr(d.adbin, d.adrelid) LIKE '%%CURRENT_DATE%%' OR" \
-	" pg_get_expr(d.adbin, d.adrelid) LIKE '%%LOCALTIME%%' OR pg_get_expr(d.adbin, d.adrelid) LIKE '%%LOCALTIMESTAMP%%')" \
+#define ATTRDEFQUERY "SELECT attname, d.adsrc, coalesce((d.adsrc LIKE '%%now()%%' OR d.adsrc LIKE '%%''now''::text%%')" \
 	" AND (a.atttypid = 'timestamp'::regtype::oid OR" \
 	" a.atttypid = 'timestamp with time zone'::regtype::oid OR" \
 	" a.atttypid = 'date'::regtype::oid OR" \
@@ -142,25 +140,9 @@ relcache_lookup(TSRewriteContext *ctx)
 	" FROM pg_catalog.pg_class c, pg_catalog.pg_attribute a " \
 	" LEFT JOIN pg_catalog.pg_attrdef d ON (a.attrelid = d.adrelid AND a.attnum = d.adnum)" \
 	" WHERE c.oid = a.attrelid AND a.attnum >= 1 AND a.attisdropped = 'f' AND c.relname = '%s'" \
-	" ORDER BY a.attnum" : \
-	"SELECT attname, d.adsrc, coalesce((d.adsrc LIKE '%%now()%%' OR d.adsrc LIKE '%%''now''::text%%' OR" \
-	" d.adsrc LIKE '%%CURRENT_TIMESTAMP%%' OR d.adsrc LIKE '%%CURRENT_TIME%%' OR d.adsrc LIKE '%%CURRENT_DATE%%' OR" \
-	" d.adsrc LIKE '%%LOCALTIME%%' OR d.adsrc LIKE '%%LOCALTIMESTAMP%%')" \
-	" AND (a.atttypid = 'timestamp'::regtype::oid OR" \
-	" a.atttypid = 'timestamp with time zone'::regtype::oid OR" \
-	" a.atttypid = 'date'::regtype::oid OR" \
-	" a.atttypid = 'time'::regtype::oid OR" \
-	" a.atttypid = 'time with time zone'::regtype::oid)" \
-    " , false)" \
-	" FROM pg_catalog.pg_class c, pg_catalog.pg_attribute a " \
-	" LEFT JOIN pg_catalog.pg_attrdef d ON (a.attrelid = d.adrelid AND a.attnum = d.adnum)" \
-	" WHERE c.oid = a.attrelid AND a.attnum >= 1 AND a.attisdropped = 'f' AND c.relname = '%s'" \
-	" ORDER BY a.attnum")
+	" ORDER BY a.attnum"
 
-#define ATTRDEFQUERY2 (Pgversion(ctx->backend)->major >= 73 ? \
-	"SELECT attname, pg_get_expr(d.adbin, d.adrelid), coalesce((pg_get_expr(d.adbin, d.adrelid) LIKE '%%now()%%' OR pg_get_expr(d.adbin, d.adrelid) LIKE '%%''now''::text%%' OR" \
-	" pg_get_expr(d.adbin, d.adrelid) LIKE '%%CURRENT_TIMESTAMP%%' OR pg_get_expr(d.adbin, d.adrelid) LIKE '%%CURRENT_TIME%%' OR pg_get_expr(d.adbin, d.adrelid) LIKE '%%CURRENT_DATE%%' OR" \
-	" pg_get_expr(d.adbin, d.adrelid) LIKE '%%LOCALTIME%%' OR pg_get_expr(d.adbin, d.adrelid) LIKE '%%LOCALTIMESTAMP%%')" \
+#define ATTRDEFQUERY2 "SELECT attname, d.adsrc, coalesce((d.adsrc LIKE '%%now()%%' OR d.adsrc LIKE '%%''now''::text%%')" \
 	" AND (a.atttypid = 'timestamp'::regtype::oid OR" \
 	" a.atttypid = 'timestamp with time zone'::regtype::oid OR" \
 	" a.atttypid = 'date'::regtype::oid OR" \
@@ -170,25 +152,9 @@ relcache_lookup(TSRewriteContext *ctx)
 	" FROM pg_catalog.pg_class c, pg_catalog.pg_attribute a " \
 	" LEFT JOIN pg_catalog.pg_attrdef d ON (a.attrelid = d.adrelid AND a.attnum = d.adnum)" \
 	" WHERE c.oid = a.attrelid AND a.attnum >= 1 AND a.attisdropped = 'f' AND c.oid = pgpool_regclass('%s')" \
-	" ORDER BY a.attnum" : \
-	"SELECT attname, d.adsrc, coalesce((d.adsrc LIKE '%%now()%%' OR d.adsrc LIKE '%%''now''::text%%' OR" \
-	" d.adsrc LIKE '%%CURRENT_TIMESTAMP%%' OR d.adsrc LIKE '%%CURRENT_TIME%%' OR d.adsrc LIKE '%%CURRENT_DATE%%' OR" \
-	" d.adsrc LIKE '%%LOCALTIME%%' OR d.adsrc LIKE '%%LOCALTIMESTAMP%%')" \
-	" AND (a.atttypid = 'timestamp'::regtype::oid OR" \
-	" a.atttypid = 'timestamp with time zone'::regtype::oid OR" \
-	" a.atttypid = 'date'::regtype::oid OR" \
-	" a.atttypid = 'time'::regtype::oid OR" \
-	" a.atttypid = 'time with time zone'::regtype::oid)" \
-    " , false)" \
-	" FROM pg_catalog.pg_class c, pg_catalog.pg_attribute a " \
-	" LEFT JOIN pg_catalog.pg_attrdef d ON (a.attrelid = d.adrelid AND a.attnum = d.adnum)" \
-	" WHERE c.oid = a.attrelid AND a.attnum >= 1 AND a.attisdropped = 'f' AND c.oid = pgpool_regclass('%s')" \
-	" ORDER BY a.attnum")
+	" ORDER BY a.attnum"
 
-#define ATTRDEFQUERY3 (Pgversion(ctx->backend)->major >= 73 ? \
-	"SELECT attname, pg_get_expr(d.adbin, d.adrelid), coalesce((pg_get_expr(d.adbin, d.adrelid) LIKE '%%now()%%' OR pg_get_expr(d.adbin, d.adrelid) LIKE '%%''now''::text%%' OR" \
-	" pg_get_expr(d.adbin, d.adrelid) LIKE '%%CURRENT_TIMESTAMP%%' OR pg_get_expr(d.adbin, d.adrelid) LIKE '%%CURRENT_TIME%%' OR pg_get_expr(d.adbin, d.adrelid) LIKE '%%CURRENT_DATE%%' OR" \
-	" pg_get_expr(d.adbin, d.adrelid) LIKE '%%LOCALTIME%%' OR pg_get_expr(d.adbin, d.adrelid) LIKE '%%LOCALTIMESTAMP%%')" \
+#define ATTRDEFQUERY3 "SELECT attname, d.adsrc, coalesce((d.adsrc LIKE '%%now()%%' OR d.adsrc LIKE '%%''now''::text%%')" \
 	" AND (a.atttypid = 'timestamp'::regtype::oid OR" \
 	" a.atttypid = 'timestamp with time zone'::regtype::oid OR" \
 	" a.atttypid = 'date'::regtype::oid OR" \
@@ -198,20 +164,7 @@ relcache_lookup(TSRewriteContext *ctx)
 	" FROM pg_catalog.pg_class c, pg_catalog.pg_attribute a " \
 	" LEFT JOIN pg_catalog.pg_attrdef d ON (a.attrelid = d.adrelid AND a.attnum = d.adnum)" \
 	" WHERE c.oid = a.attrelid AND a.attnum >= 1 AND a.attisdropped = 'f' AND c.oid = to_regclass('%s')" \
-	" ORDER BY a.attnum" : \
-	"SELECT attname, d.adsrc, coalesce((d.adsrc LIKE '%%now()%%' OR d.adsrc LIKE '%%''now''::text%%' OR" \
-	" d.adsrc LIKE '%%CURRENT_TIMESTAMP%%' OR d.adsrc LIKE '%%CURRENT_TIME%%' OR d.adsrc LIKE '%%CURRENT_DATE%%' OR" \
-	" d.adsrc LIKE '%%LOCALTIME%%' OR d.adsrc LIKE '%%LOCALTIMESTAMP%%')" \
-	" AND (a.atttypid = 'timestamp'::regtype::oid OR" \
-	" a.atttypid = 'timestamp with time zone'::regtype::oid OR" \
-	" a.atttypid = 'date'::regtype::oid OR" \
-	" a.atttypid = 'time'::regtype::oid OR" \
-	" a.atttypid = 'time with time zone'::regtype::oid)" \
-    " , false)" \
-	" FROM pg_catalog.pg_class c, pg_catalog.pg_attribute a " \
-	" LEFT JOIN pg_catalog.pg_attrdef d ON (a.attrelid = d.adrelid AND a.attnum = d.adnum)" \
-	" WHERE c.oid = a.attrelid AND a.attnum >= 1 AND a.attisdropped = 'f' AND c.oid = to_regclass('%s')" \
-	" ORDER BY a.attnum")
+	" ORDER BY a.attnum"
 
 	char *query;
 	char *table_name;
@@ -339,7 +292,7 @@ rewrite_timestamp_walker(Node *node, void *context)
 				rewrite_timestamp_insert(i_stmt, ctx);
 				ctx->relname = relname_old;
 			}
-			/* tree walker is called in rewrite_timestamp_insert() */ 
+			/* tree walker is called in rewrite_timestamp_insert() */
 			return false;
 		case T_UpdateStmt:
 			{
@@ -352,7 +305,7 @@ rewrite_timestamp_walker(Node *node, void *context)
 				rewrite_timestamp_update(u_stmt, ctx);
 				ctx->relname = relname_old;
 			}
-			/* tree walker is called in rewrite_timestamp_update() */ 
+			/* tree walker is called in rewrite_timestamp_update() */
 			return false;
 		case T_FuncCall:
 			{
@@ -375,10 +328,54 @@ rewrite_timestamp_walker(Node *node, void *context)
 				}
 			}
 			break;
+		case T_SQLValueFunction:
+			{
+
+				/* CURRENT_DATE, CURRENT_TIME, LOCALTIMESTAMP, LOCALTIME etc.
+				 * From PostgreSQL 10, timestamp conversion is changed and
+				 * SQLValueFunction is added. But Pgpool-II should use
+				 * the old timestamp translate like "'now'::text::date".
+				 * So we have to cast the node to TypeCast first.
+				 */
+				SQLValueFunction	*svf = (SQLValueFunction *) node;
+
+				if (svf->op == SVFOP_CURRENT_DATE ||
+					svf->op == SVFOP_CURRENT_TIME ||
+					svf->op == SVFOP_CURRENT_TIME_N ||
+					svf->op == SVFOP_CURRENT_TIMESTAMP ||
+					svf->op == SVFOP_CURRENT_TIMESTAMP_N ||
+					svf->op == SVFOP_LOCALTIME ||
+					svf->op == SVFOP_LOCALTIME_N ||
+					svf->op == SVFOP_LOCALTIMESTAMP ||
+					svf->op == SVFOP_LOCALTIMESTAMP_N)
+				{
+
+					TypeCast	*tc, *tc1;
+
+					tc1 = makeTypeCastFromSvfOp(svf->op);
+
+					tc = (TypeCast *) node;
+					tc->arg = tc1->arg;
+					tc->typeName = (TypeName *)copyObject(tc1->typeName);
+					tc->location = -1;
+
+					node->type = T_TypeCast;
+
+					/* rewrite `'now'::timestamp' and `'now'::text::timestamp' both */
+					if (isSystemTypeCast(tc->arg, "text"))
+						tc = (TypeCast *) tc->arg;
+
+					if (isStringConst(tc->arg, "now"))
+					{
+						tc->arg = (Node *) makeTsExpr(ctx);
+						ctx->rewrite = true;
+					}
+				}
+			}
+			break;
 		case T_TypeCast:
 			{
-				/* CURRENT_DATE, CURRENT_TIME, LOCALTIMESTAMP, LOCALTIME etc.*/
-				TypeCast	*tc = (TypeCast *) node;
+				TypeCast   *tc = (TypeCast *) node;
 
 				if ((isSystemType((Node *) tc->typeName, "date") ||
 			 		isSystemType((Node *) tc->typeName, "timestamp") ||
@@ -758,35 +755,8 @@ rewrite_timestamp(POOL_CONNECTION_POOL *backend, Node *node,
 		stmt = ((PrepareStmt *) node)->query;
 		ctx.rewrite_to_params = true;
 	}
-	/*
-	 * CopyStmt
-	 */
-	else if (IsA(node, CopyStmt) &&((CopyStmt *) node)->query != NULL)
+	else if (IsA(node, CopyStmt) && ((CopyStmt *) node)->query != NULL)
 		stmt = ((CopyStmt *) node)->query;
-	/*
-	 * ExplainStmt
-	 */
-	else if (IsA(node, ExplainStmt))
-	{
-		ListCell   *lc;
-		bool        analyze = false;
-
-		/* Check to see if this is EXPLAIN ANALYZE */
-		foreach(lc, ((ExplainStmt *) node)->options)
-		{
-			DefElem    *opt = (DefElem *) lfirst(lc);
-
-			if (strcmp(opt->defname, "analyze") == 0)
-			{
-				stmt = ((ExplainStmt *) node)->query;
-				analyze = true;
-				break;
-			}
-		}
-
-		if (!analyze)
-			return NULL;
-	}
 	else
 		stmt = node;
 
@@ -849,46 +819,6 @@ rewrite_timestamp(POOL_CONNECTION_POOL *backend, Node *node,
 			}
 		}
 	}
-	else if (IsA(stmt, CreateTableAsStmt))
-	{
-		CreateTableAsStmt *c_stmt = (CreateTableAsStmt *) stmt;
-
-		/*
-		 * CREATE TABLE t1 AS SELECT now();
-		 */
-		if (IsA(c_stmt->query, SelectStmt) && c_stmt->relkind == OBJECT_TABLE)
-		{
-			/* rewrite params */
-			raw_expression_tree_walker(
-									   (Node *) c_stmt->query,
-									   rewrite_timestamp_walker, (void *) &ctx);
-
-			rewrite = ctx.rewrite;
-		}
-	}
-	else if (IsA(stmt, SelectStmt))
-	{
-		SelectStmt *s_stmt = (SelectStmt *) stmt;
-
-		/*
-		 * SELECT now() INTO t1;
-		 */
-		if (s_stmt->intoClause)
-		{
-			raw_expression_tree_walker(
-									   (Node *) s_stmt,
-									   rewrite_timestamp_walker, (void *) &ctx);
-		}
-
-		if (s_stmt->withClause)
-		{
-			raw_expression_tree_walker(
-									   (Node *) s_stmt->withClause,
-									   rewrite_timestamp_walker, (void *) &ctx);
-		}
-
-		rewrite = ctx.rewrite;
-	}
 	else
 		;
 
@@ -959,8 +889,7 @@ bind_rewrite_timestamp(POOL_CONNECTION_POOL *backend,
 {
 	int16		 tmp2,
 				 num_params,
-				 num_formats,
-				 num_formats_new;
+				 num_formats;
 	int32		 tmp4;
 	int			 i,
 				 ts_len,
@@ -973,11 +902,10 @@ bind_rewrite_timestamp(POOL_CONNECTION_POOL *backend,
 
 #ifdef TIMESTAMPDEBUG
 	fprintf(stderr, "message length:%d\n", *len);
-	for(i = 0; i < *len; i++)
+	for(i=0;i<*len;i++)
 	{
 		fprintf(stderr, "%02x ", orig_msg[i]);
 	}
-	fprintf(stderr, "\n");
 #endif
 
 	ts = get_current_timestamp(backend);
@@ -995,78 +923,53 @@ bind_rewrite_timestamp(POOL_CONNECTION_POOL *backend,
 	/* allocate extra memory for parameter formats */
 	num_org_params = message->query_context->num_original_params;
 	new_msg = copy_to = (char *) palloc(*len + sizeof(int16) * (message->num_tsparams + num_org_params));
-
 	copy_from = orig_msg;
 
-	/* 1. portal_name */
+	/* portal_name */
 	copy_len = strlen(copy_from) + 1;
 	memcpy(copy_to, copy_from, copy_len);
-	copy_to += copy_len;
-	copy_from += copy_len;
+	copy_to += copy_len; copy_from += copy_len;
 
-	/* 2. stmt_name */
+	/* stmt_name */
 	copy_len = strlen(copy_from) + 1;
 	memcpy(copy_to, copy_from, copy_len);
-	copy_to += copy_len;
-	copy_from += copy_len;
+	copy_to += copy_len; copy_from += copy_len;
 
-	/* 3. format codes */
-
-	/* 3.1. the number of format codes */
+	/* format code */
 	memcpy(&tmp2, copy_from, sizeof(int16));
-	num_formats = ntohs(tmp2);
+	copy_len = sizeof(int16);
+	tmp2 = num_formats = ntohs(tmp2);
 
-	if (num_formats == 0)
+	if (num_formats >= 1)
 	{
-		/*
-		 * If num_formats is 0, the original message has no parameters or the parameter formats are all text,
-		 * so we don't need additional format codes since timestamp parametes use text as its format.
-		 */
-		num_formats_new = 0;
-	}
-	else
-	{
-		/* If num formats is 1, this means the specified format code is applied for all original parameters,
-		 * so enlarge message length to specify format codes for each of original paramters. */
+		/* this means the specified format code is applied all original parameters */
 		if (num_formats == 1)
+		{
 			*len += (num_org_params - 1) * sizeof(int16);
+			tmp2 += num_org_params - 1;
+		}
 
 		/* enlarge message length for timestamp parameter's formats */
 		*len += message->num_tsparams * sizeof(int16);
-		num_formats_new = num_org_params + message->num_tsparams;
+		tmp2 += message->num_tsparams;
 	}
 
-	/* copy the number of format codes */
-	tmp2 = htons(num_formats_new);
-	copy_len = sizeof(int16);
-	memcpy(copy_to, &tmp2, copy_len);
-	copy_to += copy_len;
-	copy_from += copy_len;
+	tmp2 = htons(tmp2);
+	memcpy(copy_to, &tmp2, copy_len);	/* copy number of format codes */
+	copy_to += copy_len; copy_from += copy_len;
+
+	copy_len = num_formats * sizeof(int16);
+
+	memcpy(copy_to, copy_from, copy_len);		/* copy format codes */
+	copy_to += copy_len; copy_from += copy_len;
 
-	/* 3.2. the format codes */
 	if (num_formats >= 1)
 	{
-
-		/* If num_formats is 1, copy the specified format code as numbers of original parameters */
+		/* copy the specified format code as numbers of original parameters */
 		if (num_formats == 1)
 		{
-			int16	org_format_code;
-			memcpy(&org_format_code, copy_from, sizeof(int16));
-			copy_from += copy_len;
-
-			for (i = 0; i < num_org_params; i++)
-			{
-				memcpy(copy_to, &org_format_code, sizeof(int16));
-				copy_to += sizeof(int16);
-			}
-		}
-		/* otherwize, copy the original format codes as they are*/
-		else
-		{
-			copy_len = num_formats * sizeof(int16);
-			memcpy(copy_to, copy_from, copy_len);
-			copy_to += copy_len;
-			copy_from += copy_len;
+			memcpy(copy_to, copy_from, (num_org_params - 1) * sizeof(int16));
+			copy_to += (num_org_params - 1) * sizeof(int16);
 		}
 
 		/* set additional format codes to zero(text) */
@@ -1074,8 +977,6 @@ bind_rewrite_timestamp(POOL_CONNECTION_POOL *backend,
 		copy_to += sizeof(int16) * message->num_tsparams;
 	}
 
-	/* 4. parameters */
-
 	/* num params */
 	memcpy(&tmp2, copy_from, sizeof(int16));
 	copy_len = sizeof(int16);
@@ -1084,7 +985,7 @@ bind_rewrite_timestamp(POOL_CONNECTION_POOL *backend,
 	memcpy(copy_to, &tmp2, sizeof(int16));
 	copy_to += copy_len; copy_from += copy_len;
 
-	/* original params */
+	/* params */
 	copy_len = 0;
 	for (i = 0; i < num_params; i++)
 	{
@@ -1103,7 +1004,6 @@ bind_rewrite_timestamp(POOL_CONNECTION_POOL *backend,
 	memcpy(copy_to, copy_from, copy_len);
 	copy_to += copy_len; copy_from += copy_len;
 
-	/* timestamp params */
 	tmp4 = htonl(ts_len);
 	for (i = 0; i < message->num_tsparams; i++)
 	{
@@ -1113,21 +1013,12 @@ bind_rewrite_timestamp(POOL_CONNECTION_POOL *backend,
 		copy_to += ts_len;
 	}
 
-	/* 5. result format code */
+	/* result format code */
 	memcpy(&tmp2, copy_from, sizeof(int16));
 	copy_len = sizeof(int16);
 	copy_len += sizeof(int16) * ntohs(tmp2);
 	memcpy(copy_to, copy_from, copy_len);
 
-#ifdef TIMESTAMPDEBUG
-	fprintf(stderr, "message length:%d\n", *len);
-	for(i = 0; i < *len; i++)
-	{
-		fprintf(stderr, "%02x ", new_msg[i]);
-	}
-	fprintf(stderr, "\n");
-#endif
-
 	return new_msg;
 }
 
@@ -1160,6 +1051,69 @@ static A_Const *makeStringConstFromQuery(POOL_CONNECTION_POOL *backend, char *ex
 	return con;
 }
 
+static TypeCast *
+makeTypeCastFromSvfOp(SQLValueFunctionOp op)
+{
+	TypeName *typename;
+	Node *n;
+	int location;
+
+	switch (op)
+	{
+		case SVFOP_CURRENT_DATE:
+			typename = SystemTypeName("date");
+			location = 0;
+			break;
+		case SVFOP_CURRENT_TIME:
+			typename = SystemTypeName("timetz");
+			location = 0;
+			break;
+		case SVFOP_CURRENT_TIME_N:
+			typename = SystemTypeName("timetz");
+			typename->typmods = lcons(makeIntConst(0, 0), NIL);
+			location = -3;
+			break;
+		case SVFOP_CURRENT_TIMESTAMP:
+			typename = SystemTypeName("timestamptz");
+			location = 0;
+			break;
+		case SVFOP_CURRENT_TIMESTAMP_N:
+			typename = SystemTypeName("timestamptz");
+			typename->typmods = lcons(makeIntConst(0, 0), NIL);
+			location = -3;
+			break;
+		case SVFOP_LOCALTIME:
+			typename = SystemTypeName("time");
+			location = 0;
+			break;
+		case SVFOP_LOCALTIME_N:
+			typename = SystemTypeName("time");
+			typename->typmods = lcons(makeIntConst(0, 0), NIL);
+			location = -3;
+			break;
+		case SVFOP_LOCALTIMESTAMP:
+			typename = SystemTypeName("timestamp");
+			location = 0;
+			break;
+		case SVFOP_LOCALTIMESTAMP_N:
+			typename = SystemTypeName("timestamp");;
+			typename->typmods = lcons(makeIntConst(0, 0), NIL);
+			location = -3;
+			break;
+		case SVFOP_CURRENT_ROLE:
+		case SVFOP_CURRENT_USER:
+		case SVFOP_USER:
+		case SVFOP_SESSION_USER:
+		case SVFOP_CURRENT_CATALOG:
+		case SVFOP_CURRENT_SCHEMA:
+			break;
+	}
+
+	n = makeStringConstCast("now", -1, SystemTypeName("text"));
+
+	return (TypeCast *) makeTypeCast(n, typename, location);
+}
+
 /* from nodeFuncs.c start */
 
 /*
