@@ -5,7 +5,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2020	PgPool Global Development Group
+ * Copyright (c) 2003-2016	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -102,30 +102,34 @@ void send_row_description(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backe
 }
 
 /*
- * Send the command complete and ready for query message
+ * send the command complete and ready for query message
  * to frontend.
- * If the num_row is lower than 0, it is not included
- * to the command complete message.
+ * if the num_row is passed with a -ve value it is not included
+ * to the command complete message
  */
 void send_complete_and_ready(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend,const char* message ,const int num_rows)
 {
-	int			len;
-	int			msg_len;
-	char		msg[64];
+	int len;
+	int msg_len;
+	char msg[16];
 
 	if (num_rows >= 0)
-		msg_len = snprintf(msg, sizeof(msg), "%s %d", message, num_rows);
+		msg_len = snprintf(msg, 16, "%s %d", message,num_rows);
 	else
-		msg_len = snprintf(msg, sizeof(msg), "%s", message);
+		msg_len = snprintf(msg, 16, "%s", message);
+
+	/* if we had more than 16 bytes, including '\0', the string was truncatured
+	 * shouldn't happen though, as it would means more than "SELECT 99999999" */
+	if (msg_len > 15) msg_len = 15;
 
 	/* complete command response */
 	pool_write(frontend, "C", 1);
 	if (MAJOR(backend) == PROTO_MAJOR_V3)
 	{
-		len = htonl(4 + msg_len + 1);
+		len = htonl(4 + strlen(msg)+1);
 		pool_write(frontend, &len, sizeof(len));
 	}
-	pool_write(frontend, msg, msg_len + 1);
+	pool_write(frontend, msg, strlen(msg)+1);
 
 	/* ready for query */
 	pool_write(frontend, "Z", 1);
@@ -235,16 +239,6 @@ POOL_REPORT_CONFIG* get_config(int *nrows)
 	StrNCpy(status[i].desc, "directory containing CA root certificate(s)", POOLCONFIG_MAXDESCLEN);
 	i++;
 
-	StrNCpy(status[i].name, "ssl_ciphers", POOLCONFIG_MAXNAMELEN);
-	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%s", pool_config->ssl_ciphers);
-	StrNCpy(status[i].desc, "allowed SSL ciphers", POOLCONFIG_MAXDESCLEN);
-	i++;
-
-	StrNCpy(status[i].name, "ssl_prefer_server_ciphers", POOLCONFIG_MAXNAMELEN);
-	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%d", pool_config->ssl_prefer_server_ciphers);
-	StrNCpy(status[i].desc, "Use server's SSL cipher preferences", POOLCONFIG_MAXDESCLEN);
-	i++;
-
 	/* POOLS */
 
 	/* - Pool size -  */
@@ -276,7 +270,7 @@ POOL_REPORT_CONFIG* get_config(int *nrows)
 
 	StrNCpy(status[i].name, "child_max_connections", POOLCONFIG_MAXNAMELEN);
 	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%d", pool_config->child_max_connections);
-	StrNCpy(status[i].desc, "if max_connections received, child exits", POOLCONFIG_MAXDESCLEN);
+	StrNCpy(status[i].desc, "if max_connections received, chile exits", POOLCONFIG_MAXDESCLEN);
 	i++;
 
 	StrNCpy(status[i].name, "connection_life_time", POOLCONFIG_MAXNAMELEN);
@@ -903,7 +897,7 @@ POOL_REPORT_CONFIG* get_config(int *nrows)
 		i++;
 
 		snprintf(status[i].name, POOLCONFIG_MAXNAMELEN, "backend_status%d", j);
-		snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%s",backend_status_to_str(BACKEND_INFO(j).backend_status) );
+		snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%s",backend_status_to_str(&BACKEND_INFO(j)) );
 		snprintf(status[i].desc, POOLCONFIG_MAXDESCLEN, "status of backend #%d", j);
 		i++;
 
@@ -1154,7 +1148,7 @@ POOL_REPORT_NODES* get_nodes(int *nrows)
 		snprintf(nodes[i].node_id, 	POOLCONFIG_MAXIDLEN, 	"%d", 	i);
 	    StrNCpy(nodes[i].hostname, 	bi->backend_hostname, 		strlen(bi->backend_hostname)+1);
 	    snprintf(nodes[i].port, 	POOLCONFIG_MAXPORTLEN, "%d", 	bi->backend_port);
-	    snprintf(nodes[i].status, 	POOLCONFIG_MAXSTATLEN, 	"%s", 	backend_status_to_str(bi->backend_status));
+	    snprintf(nodes[i].status, 	POOLCONFIG_MAXSTATLEN, 	"%s", 	backend_status_to_str(bi));
 	    snprintf(nodes[i].lb_weight, POOLCONFIG_MAXWEIGHTLEN, "%f", bi->backend_weight/RAND_MAX);
 	    snprintf(nodes[i].select, POOLCONFIG_MAXWEIGHTLEN, UINT64_FORMAT, stat_get_select_count(i));
 	    snprintf(nodes[i].load_balance_node, POOLCONFIG_MAXWEIGHTLEN, "%s",
